@@ -940,7 +940,7 @@ class Face3D(Base2DIn3D):
 
         return grid_mesh3d
 
-    def countour_by_number(self, contour_count, direction_vector, flip_side, tolerance):
+    def contour_by_number(self, contour_count, direction_vector, flip_side, tolerance):
         """Generate a list of LineSegment3D objects contouring the face.
 
         Args:
@@ -982,8 +982,8 @@ class Face3D(Base2DIn3D):
             contours = [l_seg for l_seg in contours if l_seg.length >= tolerance]
         return contours
 
-    def countour_by_distance_between(self, distance, direction_vector, flip_side,
-                                     tolerance):
+    def contour_by_distance_between(self, distance, direction_vector, flip_side,
+                                    tolerance):
         """Generate a list of LineSegment3D objects contouring the face.
 
         Args:
@@ -1030,8 +1030,8 @@ class Face3D(Base2DIn3D):
             contours = [l_seg for l_seg in contours if l_seg.length >= tolerance]
         return contours
 
-    def countour_fins_by_number(self, fin_count, depth, offset, angle,
-                                contour_vector, flip_side, tolerance):
+    def contour_fins_by_number(self, fin_count, depth, offset, angle,
+                               contour_vector, flip_side, tolerance):
         """Generate a list of Fac3D objects over this face (like louvers or fins).
 
         Args:
@@ -1055,12 +1055,12 @@ class Face3D(Base2DIn3D):
                 than the tolerance.
         """
         extru_vec = self._get_fin_extrusion_vector(depth, angle, contour_vector)
-        contours = self.countour_by_number(
+        contours = self.contour_by_number(
             fin_count, contour_vector, flip_side, tolerance)
         return self._get_extrusion_fins(contours, extru_vec, offset)
 
-    def countour_fins_by_distance_between(self, distance, depth, offset, angle,
-                                          contour_vector, flip_side, tolerance):
+    def contour_fins_by_distance_between(self, distance, depth, offset, angle,
+                                         contour_vector, flip_side, tolerance):
         """Generate a list of Fac3D objects over this face (like louvers or fins).
 
         Args:
@@ -1084,7 +1084,7 @@ class Face3D(Base2DIn3D):
                 than the tolerance.
         """
         extru_vec = self._get_fin_extrusion_vector(depth, angle, contour_vector)
-        contours = self.countour_by_distance_between(
+        contours = self.contour_by_distance_between(
             distance, contour_vector, flip_side, tolerance)
         return self._get_extrusion_fins(contours, extru_vec, offset)
 
@@ -1912,15 +1912,22 @@ class Face3D(Base2DIn3D):
             verts: The vertices to be used to extract the normal.
         """
         try:
-            x1, y1, z1 = Face3D._normal_from_3pts(verts[-2], verts[-1], verts[0])
-            x2, y2, z2 = Face3D._normal_from_3pts(verts[-1], verts[0], verts[1])
-            normal = [x1 + x2, y1 + y2, z1 + z2]
-            # walk around the whole shape to avoid colinear vertices
+            # walk around the shape and get cross products and magnitudes
+            cprod1, d1 = Face3D._normal_from_3pts(verts[-2], verts[-1], verts[0])
+            cprod2, d2 = Face3D._normal_from_3pts(verts[-1], verts[0], verts[1])
+            cprods, ds = [cprod1, cprod2], [d1, d2]
             for i in range(len(verts) - 2):
-                x, y, z = Face3D._normal_from_3pts(*verts[i:i + 3])
-                normal[0] += x
-                normal[1] += y
-                normal[2] += z
+                cprodx, dx = Face3D._normal_from_3pts(*verts[i:i + 3])
+                cprods.append(cprodx)
+                ds.append(dx)
+            # sum together the cross products of any vertices that are not colinear
+            min_d = (sum(ds) / len(ds)) * 1e-3  # rel tolerance for colinear vertices
+            normal = [0, 0, 0]
+            for cprodx, dx in zip(cprods, ds):
+                if dx > min_d:
+                    normal[0] += cprodx[0] / dx
+                    normal[1] += cprodx[1] / dx
+                    normal[2] += cprodx[2] / dx
         except Exception as e:
             raise ValueError('Incorrect vertices input for Face3D:\n\t{}'.format(e))
         return Plane(Vector3D(normal[0], normal[1], normal[2]), verts[0]) \
@@ -1944,9 +1951,7 @@ class Face3D(Base2DIn3D):
                   v1[0] * v2[1] - v1[1] * v2[0])
         # normalize the vector to make it a unit vector
         d = math.sqrt(c_prod[0] ** 2 + c_prod[1] ** 2 + c_prod[2] ** 2)
-        if d < 1e-9:  # effectively duplicate vertices in triplet
-            return (0, 0, 0)
-        return (c_prod[0] / d, c_prod[1] / d, c_prod[2] / d)
+        return c_prod, d
 
     @staticmethod
     def _corner_pt_verts(corner_pt, verts3d, verts2d):
